#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-HXX1zFqFj61IZuayvL28KA
key:                  rvar-0.3.0.2-HXX1zFqFj61IZuayvL28KA
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  9eac778062d2f3f4e77602f13f9b9c05
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-HXX1zFqFj61IZuayvL28KA
depends:
    MonadPrompt-1.0.0.5-45KZ6GehS5A3DH7BS5Bf5a base-4.18.2.1
    bytestring-0.11.5.3 mtl-2.3.1 random-1.2.1.3-1Uit38DFsvW5UeAKObGtgy
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

